Modules
Macros
- serde_
string_ enum - Adds display and to_string implementation to serde enum types.
- tag
- Tag inline macro.
- tags
- Tags inline macro.
Structs
- Absolute
Path - Absolute Path.
- Absolute
Path Owned - Owned Absolute Path.
- Block
- Block
- Block
Links - Block
Serializer - DagCbor Block Serializer/Deserializer.
- Block
Stat - Block
Storage Clone Settings - Clock
- Lamport Clock.
- CoCid
- CoConnectivity
- CoId
- CO Unique ID.
- CoInvite
Metadata - CoList
- CoList stored values in a sequence.
- CoList
Index - CoList index - non continous.
- CoList
Transaction - CoMap
- CoMap
Transaction - CoSet
- CoSet
Transaction - Components
- Path components.
- Core
Block Storage - Core
Name - Typed core name.
- Default
Node Serializer - Default
Params - Dynamic
CoDate - Entry
- Guard
Input - Guard
Output - Ignore
Filter - Filter out Cid links.
- Join
Filter - Lazy
Transaction - Lazy transaction that only opens the transaction when used.
- Link
- A (serializable) typed link.
- LsmTree
Map - LSM Tree Instance.
- LsmTree
MapSettings - Mapped
Cid - Mapped Cid.
- Monotonic
CoDate - Multi
Codec Error - Multi Codec Error.
- Network
CoHeads - CO Heads protocol.
- Network
DidDiscovery - DID Discovery protocol.
- Network
Peer - Direct peer connection.
- Network
Rendezvous - Rendezvouz protocol.
- Node
Builder - Create a balances merkle tree of Node blocks.
- Node
Stream - Stream node items.
- Option
Link - A (serializable) typed link.
- Path
- Path. Can be relative or absolute.
- Path
Owned - Owned Path.
- Reducer
Action - Reducer
Input - Reducer
Output - Relative
Path - Relative Path.
- Relative
Path Owned - OWned Relative Path.
- Secret
- Simple wrapper type for secrents to not escape them.
- Signed
Entry - Static
CoDate - Tags
- Tags.
- Total
Float64 - f64 float wich uses total order from IEEE 754 (2008 revision).
- WeakCid
- A CID that will be serialized as just bytes and will not be returned by
crate::BlockLinks. - Weak
CoReference Filter - Filter out
CoReference::Weakblocks. - With
CoMetadata
Enums
- Block
Diff - Block
Error - Block
Serializer Error - Cbor
Error - CoInvite
- Sets behaviour for incoming invites
- CoJoin
- Sets behaviour for join requests
- CoNetwork
- CO Participant network feature(s) tag.
- CoReference
- Wrapps a reference/link/Cid and applies attributes useful in context of a Co.
- CoTimeout
- CO timeout setting.
- Component
- Path component.
- Diagnostic
Message - Json
Error - Known
Multi Codec - Known Muiticodecs See: https://github.com/multiformats/multicodec/blob/master/table.csv
- Known
Tags - Metadata
- Multi
Codec - MultiCodec matching utility.
- Network
- Network service connectivity description.
- Node
- Node
Builder Error - Node
Reader Error - Option
Mapped Cid - Simple type to make mapped Cid’s clear.
- Path
Error - Storage
Error - TagValue
- Tag Value
- Tags
Expr - Tags match pattern.
Constants
Traits
- AnyBlock
Storage - Utility type to document that any block storage implementation is accepted.
- Block
Diff Follow - Block
Links Filter - Block
Storage - Block
Storage Ext - Block
Storage Store Params - Block storage with custom store params.
- Clone
With Block Storage Settings - CoDate
- CoMetadata
- Special CO metadata.
- CoTry
Stream Ext - IsDefault
- Simple trait to check if the current value is the default.
- Known
Tag - Linkable
- Node
Serializer - PathExt
- Storage
- Storage interface.
- Store
Params - Streamable
- TagMatcher
- A type that can be matched against a tag.
- TagPattern
- A type that can be used as pattern to be matched against a
TagMatcher. - Transactionable
- Collection which supports transactions.
Functions
- block_
diff - Find added/removed references in blocks.
If a
Cidis referenced multiple times it will also returnes multiple times. This diff works recursively - all added/removedCidat any depth will be returned. However there is a look-ahead depth limit, how many nodes are looked down to reuse references (defaults to1). - block_
diff_ added_ with_ parent - Find added references in blocks with its parent.
This diff works recursively - all added
Cidat any depth will be returned. However there is a look-ahead depth limit, how many nodes are looked down to reuse references (defaults to1). - cid_
to_ raw - from_
cbor - Deserialize from CBOR (using dag-json).
- from_
json - Deserialize from JSON string (using dag-json).
- from_
json_ string - Deserialize from JSON string (using dag-json).
- node_
reader - raw_
to_ cid - reducer_
action_ core - Read
coreproperty from aReducerAction. - reducer_
action_ core_ from_ storage - Read
coreproperty from aReducerAction. - to_cbor
- Serialize
valueto CBOR string (using dag-json). - to_json
- Serialize
valueto JSON string (using dag-json). - to_
json_ string - Serialize
valueto JSON string (using dag-json). - unixfs_
add - Add stream as unixfs file to storage. The last CID in the result is the root.
- unixfs_
cat_ buffer - Read unixfs file into buffer.
- unixfs_
encode_ buffer - Encode buffer into blocks. The last block in the result is the root.
- unixfs_
stream - Read unixfs file as chunked stream.