#[non_exhaustive]pub enum CoReference<T> {
Weak(T),
}Expand description
Wrapps a reference/link/Cid and applies attributes useful in context of a Co.
- A
CoReferenceshould be encoded withcrate::KnownMultiCodec::CoReference. - A
CoReferenceshould be used with a narrow scope so that only the links to it are moved around. - A
CoReferenceshould be used for cross Co references to state and heads as this has special semantics for example encryption mapping.
FAQ
When to use CoReference::Weak and when [co_primitives::WeakCid]?
Use CoReference::Weak when you want to reference a root.
When the garbage collection reaches a CoReference::Weak it will not try to keep it alve with its parent.
Example: Keeping a historic root for reference or fast traversing.
Use [co_primitives::WeakCid] when the reference should not been handled as a link and will not be
accessed/traversed using this reference.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Weak(T)
Handle the reference as a weak reference. Used for reference counting.
Implementations
Sourceimpl<T> CoReference<T>
impl<T> CoReference<T>
pub fn into_value(self) -> T
pub fn to_block(&self) -> Result<Block, BlockSerializerError>where
T: Serialize,