block_diff_added_with_parent

Function block_diff_added_with_parent 

pub fn block_diff_added_with_parent<S, F>(
    storage: S,
    prev: Option<Cid>,
    next: Cid,
    block_links: BlockLinks,
    look_ahead_depth: Option<u8>,
    follow: F,
) -> impl Stream<Item = Result<(Option<Cid>, Cid), StorageError>>
where S: BlockStorage + Clone + 'static, F: BlockDiffFollow + 'static,
Find added references in blocks with its parent. This diff works recursively - all added Cid at any depth will be returned. However there is a look-ahead depth limit, how many nodes are looked down to reuse references (defaults to 1).

Args

  • follow - Whether to follow this Cid or not.