CoListTransaction

Struct CoListTransaction 

pub struct CoListTransaction<S, V>
where S: AnyBlockStorage, V: Clone + Serialize + DeserializeOwned + Send + Sync + 'static,
{ /* private fields */ }

Implementations

Source

impl<S, V> CoListTransaction<S, V>
where S: AnyBlockStorage, V: Clone + Serialize + DeserializeOwned + Send + Sync + 'static,

pub async fn get(&self, key: &CoListIndex) -> Result<Option<V>, StorageError>

pub async fn contains(&self, key: &CoListIndex) -> Result<bool, StorageError>

pub fn stream( &self, ) -> impl Stream<Item = Result<(CoListIndex, V), StorageError>> + '_

pub fn reverse_stream( &self, ) -> impl Stream<Item = Result<(CoListIndex, V), StorageError>> + '_

pub async fn insert( &mut self, index: CoListIndex, value: V, ) -> Result<CoListIndex, StorageError>

Insert value after index shifting all elements after to the right.

pub async fn insert_before( &mut self, index: CoListIndex, value: V, ) -> Result<CoListIndex, StorageError>

Insert value at index shifting all elements at or after to the right.

pub async fn set( &mut self, key: CoListIndex, value: V, ) -> Result<(), StorageError>

Insert (set/replace) value to index.

pub async fn push(&mut self, value: V) -> Result<CoListIndex, StorageError>
where S: AnyBlockStorage,

Push as last value.

pub async fn pop(&mut self) -> Result<Option<(CoListIndex, V)>, StorageError>
where S: AnyBlockStorage,

Pop last element.

pub async fn pop_front( &mut self, ) -> Result<Option<(CoListIndex, V)>, StorageError>
where S: AnyBlockStorage,

Pop first element.

pub async fn remove( &mut self, key: CoListIndex, ) -> Result<Option<V>, StorageError>

Remove given element and return the value.

pub async fn update_or_insert<F>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
where V: Default, F: FnOnce(&mut V) + Send,

Update (or insert default) value.

pub async fn try_update_or_insert_async<F, Fut>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
where V: Default, F: FnOnce(V) -> Fut + Send, Fut: Future<Output = Result<V, StorageError>> + Send,

Update (or insert default) value.

pub async fn update<F>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
where F: FnOnce(&mut V) + Send,

Update value, ignore if key not exists.

pub async fn try_update_async<F, Fut>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
where F: FnOnce(V) -> Fut + Send, Fut: Future<Output = Result<V, StorageError>> + Send,

Update value, ignore if key not exists.

pub async fn store(&mut self) -> Result<CoList<V>, StorageError>

Store as new CoList