pub struct Tags(/* private fields */);Expand description
Tags.
Implementations
Sourceimpl Tags
impl Tags
pub fn new() -> Self
pub fn merge(a: Self, b: Self) -> Self
Sourcepub fn extend(&mut self, tags: impl IntoIterator<Item = Tag>)
pub fn extend(&mut self, tags: impl IntoIterator<Item = Tag>)
Insert mutiple tags.
Tags that equal exactly (key and value) will be skipped. All others will be added.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Contains tag with key.
Sourcepub fn set(&mut self, tags: impl Into<Tags>)
pub fn set(&mut self, tags: impl Into<Tags>)
Set tag(s). By removing all tags with the same key before insert.
Sourcepub fn clear(&mut self, tags: Option<&Tags>) -> bool
pub fn clear(&mut self, tags: Option<&Tags>) -> bool
Remove specified tags.
If no tags are specified all tags will be removed.
Returns true if tags has changed.
Sourcepub fn clear_key(&mut self, key: &str)
pub fn clear_key(&mut self, key: &str)
Remove tags with key. If no tags are specified all tags will be removed.
pub fn matches<P: TagPattern>(&self, pattern: &P) -> bool
Sourcepub fn string(&self, key: &str) -> Option<&str>
pub fn string(&self, key: &str) -> Option<&str>
Get first tag value (that is a string) for given key.