BlockStorageStoreParams

Trait BlockStorageStoreParams 

pub trait BlockStorageStoreParams: BlockStorage + 'static {
    type StoreParams: StoreParams;
}
Block storage with custom store params.

Required Associated Types

Implementors

Source

impl BlockStorageStoreParams for CoreBlockStorage

We do not want dynamic block limits in cores as this breaks determinism. Force all blocks created on cores to be max. 1MiB.