pub trait TagMatcher {
// Required method
fn matches_tag(&self, key: &str, value: &TagValue) -> bool;
}Expand description
A type that can be matched against a tag.
pub trait TagMatcher {
// Required method
fn matches_tag(&self, key: &str, value: &TagValue) -> bool;
}A type that can be matched against a tag.