pub struct CoListTransaction<S, V>{ /* private fields */ }Implementations
Sourceimpl<S, V> CoListTransaction<S, V>
impl<S, V> CoListTransaction<S, V>
pub async fn get(&self, key: &CoListIndex) -> Result<Option<V>, StorageError>
pub async fn contains(&self, key: &CoListIndex) -> Result<bool, StorageError>
pub fn stream( &self, ) -> impl Stream<Item = Result<(CoListIndex, V), StorageError>> + '_
pub fn reverse_stream( &self, ) -> impl Stream<Item = Result<(CoListIndex, V), StorageError>> + '_
Sourcepub async fn insert(
&mut self,
index: CoListIndex,
value: V,
) -> Result<CoListIndex, StorageError>
pub async fn insert( &mut self, index: CoListIndex, value: V, ) -> Result<CoListIndex, StorageError>
Insert value after index shifting all elements after to the right.
Sourcepub async fn insert_before(
&mut self,
index: CoListIndex,
value: V,
) -> Result<CoListIndex, StorageError>
pub async fn insert_before( &mut self, index: CoListIndex, value: V, ) -> Result<CoListIndex, StorageError>
Insert value at index shifting all elements at or after to the right.
Sourcepub async fn set(
&mut self,
key: CoListIndex,
value: V,
) -> Result<(), StorageError>
pub async fn set( &mut self, key: CoListIndex, value: V, ) -> Result<(), StorageError>
Insert (set/replace) value to index.
Sourcepub async fn push(&mut self, value: V) -> Result<CoListIndex, StorageError>where
S: AnyBlockStorage,
pub async fn push(&mut self, value: V) -> Result<CoListIndex, StorageError>where
S: AnyBlockStorage,
Push as last value.
Sourcepub async fn pop(&mut self) -> Result<Option<(CoListIndex, V)>, StorageError>where
S: AnyBlockStorage,
pub async fn pop(&mut self) -> Result<Option<(CoListIndex, V)>, StorageError>where
S: AnyBlockStorage,
Pop last element.
Sourcepub async fn pop_front(
&mut self,
) -> Result<Option<(CoListIndex, V)>, StorageError>where
S: AnyBlockStorage,
pub async fn pop_front(
&mut self,
) -> Result<Option<(CoListIndex, V)>, StorageError>where
S: AnyBlockStorage,
Pop first element.
Sourcepub async fn remove(
&mut self,
key: CoListIndex,
) -> Result<Option<V>, StorageError>
pub async fn remove( &mut self, key: CoListIndex, ) -> Result<Option<V>, StorageError>
Remove given element and return the value.
Sourcepub async fn update_or_insert<F>(
&mut self,
key: CoListIndex,
update: F,
) -> Result<(), StorageError>
pub async fn update_or_insert<F>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
Update (or insert default) value.
Sourcepub async fn try_update_or_insert_async<F, Fut>(
&mut self,
key: CoListIndex,
update: F,
) -> Result<(), StorageError>
pub async fn try_update_or_insert_async<F, Fut>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
Update (or insert default) value.
Sourcepub async fn update<F>(
&mut self,
key: CoListIndex,
update: F,
) -> Result<(), StorageError>
pub async fn update<F>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
Update value, ignore if key not exists.
Sourcepub async fn try_update_async<F, Fut>(
&mut self,
key: CoListIndex,
update: F,
) -> Result<(), StorageError>
pub async fn try_update_async<F, Fut>( &mut self, key: CoListIndex, update: F, ) -> Result<(), StorageError>
Update value, ignore if key not exists.