pub trait BlockStorageStoreParams: BlockStorage + 'static {
type StoreParams: StoreParams;
}Expand description
Block storage with custom store params.
Required Associated Types
type StoreParams: StoreParams
Implementors
Sourceimpl BlockStorageStoreParams for CoreBlockStorage
We do not want dynamic block limits in cores as this breaks determinism.
Force all blocks created on cores to be max. 1MiB.
impl BlockStorageStoreParams for CoreBlockStorage
We do not want dynamic block limits in cores as this breaks determinism. Force all blocks created on cores to be max. 1MiB.